sox

package module
v0.0.0-...-4cb7389 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2016 License: BSD-3-Clause Imports: 3 Imported by: 0

README

Convert/Encode/Resample wav files using libsox.

Do not use yet

Supported formats:

  • G771a
  • G711u
  • GSM
  • Wav at 8kHz and 16Khz
  • MP3 at 16Khz
  • Ogg at 16Khz
  • Flac at 16Khz

Copyright (C) 2016, Lefteris Zafiris zaf@fastmail.com

This program is free software, distributed under the terms of the BSD 3-Clause License. See the LICENSE file at the top of the source tree.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Convert

func Convert(inputData []byte, inputFormat string, outputFormat string) (outData []byte, err error)

Convert wav files

func FormatInit

func FormatInit() (err error)

FormatInit Initialise sox_formats

func FormatQuit

func FormatQuit()

FormatQuit quits sox_formats

func Init

func Init() (err error)

Init Initialise sox

func Quit

func Quit() (err error)

Quit sox

Types

This section is empty.

Directories

Path Synopsis

Jump to