package
module
Version:
v0.0.0-...-4cb7389
Opens a new window with list of versions in this module.
Published: Sep 10, 2016
License: BSD-3-Clause
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Convert/Encode/Resample wav files using libsox.
Do not use yet
Supported formats:
- G771a
- G711u
- GSM
- Wav at 8kHz and 16Khz
- MP3 at 16Khz
- Ogg at 16Khz
- Flac at 16Khz
Copyright (C) 2016, Lefteris Zafiris zaf@fastmail.com
This program is free software, distributed under the terms of
the BSD 3-Clause License. See the LICENSE file
at the top of the source tree.
Documentation
¶
func FormatInit() (err error)
FormatInit Initialise sox_formats
FormatQuit quits sox_formats
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.